Module const_irc_message_parser::parameters
source · Expand description
Methods for parsing and extracting information from Parameters.
Purpose
Parameters are part of the IRC Message Protocol.
If present, they occur at the end of the IrcMsg after the Command.
How many there are and what they mean depend on the Command.
IRC servers can send a Command with more Parameters than the specification indicates.
IRC clients must be able to accept a Command and process it even when it contains more
Parameters than expected.
Structs
- All the parameters of an
IrcMsg.
Enums
- The possible types of errors when parsing
Parameters.