Method for checking equivalency of slices using IrcCaseMapping.
Purpose
IRC servers advertise which casemapping approach they use in the RPL_ISUPPORT (005) numeric IrcMsg.
A CASEMAPPING ISupportToken will specify which approach the server uses.
The casemapping is performed on client names, server names and channel names.
Enforcing casemapping can prevent confusion.
Enums
- IrcCase
Mapping - The possible casemapping approaches.