pub enum Command<'msg> {
    Named(&'msg str),
    Numeric(&'msg str),
}
The command of an IrcMsg.

Variants



Named(&'msg str)

A Command in the form of a word.



Numeric(&'msg str)

A 3 digit number represented as a string.

Implementations

source

impl<'msg> Command<'msg>

source

pub const fn parse( input: &'msg [u8], params_amount: usize ) -> Result<Self, CommandError<'_>>

Generates a Command from a slice of bytes and number of Parameters.

Errors

Will return Err if the input is empty, contains anything but ascii alphanumeric characters, is an unsupported Named/Numeric command or is provided too few parameters. Please file a bug report if you want to add support for a missing Named/Numeric command or the parameters required are too low.